@@ -48,15 +48,11 @@ class Configure(config.package.Package):
     self.usingMPIUni      = 0
     self.shared           = 0
     # local state
-    self.commf2c          = 0
-    self.commc2f          = 0
     self.needBatchMPI     = 1
     self.alternativedownload = 'mpich'
     self.haveReduceLocal  = 0
     # support MPI-3 process shared memory
     self.support_mpi3_shm = 0
-    # support MPI-3 non-blocking collectives
-    self.support_mpi3_nbc = 0
     self.mpi_pkg_version  = ''
     self.mpi_pkg          = '' # mpich,mpich2,mpich3,openmpi,intel,intel2,intel3
 
@@ -253,10 +249,13 @@ shared libraries and run with --known-mpi-shared-libraries=1')
       # Support for spaces and () in executable names; also needs to handle optional arguments at the end
       # TODO: This support for spaces and () should be moved to core BuildSystem
       self.mpiexec = self.mpiexec.replace(' ', r'\\ ').replace('(', r'\\(').replace(')', r'\\)').replace(r'\ -',' -')
-      if (hasattr(self, 'ompi_major_version') and int(self.ompi_major_version) >= 3):
-        (out, err, ret) = Configure.executeShellCommand(self.mpiexec+' -help all', checkCommand = noCheck, timeout = 60, log = self.log, threads = 1)
-        if out.find('--oversubscribe') >=0:
-          mpiexecargs += ' --oversubscribe'
+      if hasattr(self, 'ompi_major_version'):
+        if int(self.ompi_major_version) >= 5:
+          mpiexecargs += ' --oversubscribe' # alias to --map-by :OVERSUBSCRIBE
+        elif int(self.ompi_major_version) >= 3:
+          (out, err, ret) = Configure.executeShellCommand(self.mpiexec+' -help all', checkCommand = noCheck, timeout = 60, log = self.log, threads = 1)
+          if out.find('--oversubscribe') >=0:
+            mpiexecargs += ' --oversubscribe'
 
     self.getExecutable(self.mpiexec, getFullPath=1, resultName='mpiexecExecutable',setMakeMacro=0)
 
@@ -282,13 +281,13 @@ shared libraries and run with --known-mpi-shared-libraries=1')
       self.logWrite('Unable to run '+self.mpiexec+' with option "-n 1 printenv"\nThis could be ok, some MPI implementations such as SGI produce a non-zero status with non-MPI programs\n'+out+err)
     else:
       if out.find('MPIR_CVAR_CH3') > -1:
-        if hasattr(self,'ompi_major_version'): raise RuntimeError("Your libraries are from OpenMPI but it appears your mpiexec is from MPICH");
+        if hasattr(self,'ompi_major_version'): raise RuntimeError("Your libraries are from Open MPI but it appears your mpiexec is from MPICH");
         self.addDefine('HAVE_MPIEXEC_ENVIRONMENTAL_VARIABLE', 'MPIR_CVAR_CH3')
       elif  out.find('MPIR_CVAR_CH3') > -1:
-        if hasattr(self,'ompi_major_version'): raise RuntimeError("Your libraries are from OpenMPI but it appears your mpiexec is from MPICH");
+        if hasattr(self,'ompi_major_version'): raise RuntimeError("Your libraries are from Open MPI but it appears your mpiexec is from MPICH");
         self.addDefine('HAVE_MPIEXEC_ENVIRONMENTAL_VARIABLE', 'MPICH')
       elif out.find('OMPI_COMM_WORLD_SIZE') > -1:
-        if hasattr(self,'mpich_numversion'): raise RuntimeError("Your libraries are from MPICH but it appears your mpiexec is from OpenMPI");
+        if hasattr(self,'mpich_numversion'): raise RuntimeError("Your libraries are from MPICH but it appears your mpiexec is from Open MPI");
         self.addDefine('HAVE_MPIEXEC_ENVIRONMENTAL_VARIABLE', 'OMP')
     if hasattr(self,'isNecMPI'):
       (out, err, ret) = Configure.executeShellCommand(self.mpiexec+' -n 1 -V /usr/bin/true', checkCommand = noCheck, timeout = 120, threads = 1, log = self.log)
@@ -350,13 +349,13 @@ shared libraries and run with --known-mpi-shared-libraries=1')
                 self.logPrint("Exception: while running ping skipping ping check\n")
 
               if not hostnameworks:
-                # Note: host may not work on MacOS, this is normal
+                # Note: host may not work on macOS, this is normal
                 self.getExecutable('host')
                 if hasattr(self,'host'):
                   try:
                     (ok, err, ret) = Configure.executeShellCommand(self.host + ' '+ hostname, timeout = 60, log = self.log, threads = 1)
                     self.logPrint("Return code from host: %s\n" % ret)
-                    # host works even with broken VPN is is not a useful test
+                    # host works even with broken VPN it is not a useful test
                   except:
                     self.logPrint("Exception: while running host skipping host check\n")
 
@@ -414,21 +413,12 @@ Unable to run hostname to check the network')
     '''):
       raise RuntimeError('PETSc requires some of the MPI-2.0 (1997), MPI-2.1 (2008) functions - they are not available with the specified MPI library')
 
-    if self.checkLink('#include <mpi.h>\n', 'int count=2; int blocklens[2]={0,1}; MPI_Aint indices[2]={0,1}; MPI_Datatype old_types[2]={MPI_INT,MPI_DOUBLE}; MPI_Datatype *newtype = 0;\n \
+    if not self.checkLink('#include <mpi.h>\n', 'int count=2; int blocklens[2]={0,1}; MPI_Aint indices[2]={0,1}; MPI_Datatype old_types[2]={MPI_INT,MPI_DOUBLE}; MPI_Datatype *newtype = 0;\n \
                                              if (MPI_Type_create_struct(count, blocklens, indices, old_types, newtype)) { }\n'):
-      self.haveTypeCreateStruct = 1
-    else:
-      self.haveTypeCreateStruct = 0
       self.framework.addDefine('MPI_Type_create_struct(count,lens,displs,types,newtype)', 'MPI_Type_struct((count),(lens),(displs),(types),(newtype))')
-    if self.checkLink('#include <mpi.h>\n', 'MPI_Comm_errhandler_fn * p_err_fun = 0; MPI_Errhandler * p_errhandler = 0; if (MPI_Comm_create_errhandler(p_err_fun,p_errhandler)) { }\n'):
-      self.haveCommCreateErrhandler = 1
-    else:
-      self.haveCommCreateErrhandler = 0
+    if not self.checkLink('#include <mpi.h>\n', 'MPI_Comm_errhandler_fn * p_err_fun = 0; MPI_Errhandler * p_errhandler = 0; if (MPI_Comm_create_errhandler(p_err_fun,p_errhandler)) { }\n'):
       self.framework.addDefine('MPI_Comm_create_errhandler(p_err_fun,p_errhandler)', 'MPI_Errhandler_create((p_err_fun),(p_errhandler))')
-    if self.checkLink('#include <mpi.h>\n', 'if (MPI_Comm_set_errhandler(MPI_COMM_WORLD,MPI_ERRORS_RETURN)) { }\n'):
-      self.haveCommSetErrhandler = 1
-    else:
-      self.haveCommSetErrhandler = 0
+    if not self.checkLink('#include <mpi.h>\n', 'if (MPI_Comm_set_errhandler(MPI_COMM_WORLD,MPI_ERRORS_RETURN)) { }\n'):
       self.framework.addDefine('MPI_Comm_set_errhandler(comm,p_errhandler)', 'MPI_Errhandler_set((comm),(p_errhandler))')
     if self.checkLink('#include <mpi.h>\n', 'if (MPI_Reduce_local(0, 0, 0, MPI_INT, MPI_SUM)) { }\n'): # MPI_Reduce_local is in MPI-2.2
       self.haveReduceLocal = 1
@@ -500,7 +490,6 @@ Unable to run hostname to check the network')
                         if (MPI_Ibarrier(MPI_COMM_WORLD,&req)) return 0;
                       '''):
       self.addDefine('HAVE_MPI_NONBLOCKING_COLLECTIVES', 1)
-      self.support_mpi3_nbc = 1
     if self.checkLink('#include <mpi.h>\n',
                       'MPI_Comm distcomm; \n\
                        MPI_Request req; \n\
@@ -510,7 +499,7 @@ Unable to run hostname to check the network')
       self.addDefine('HAVE_MPI_NEIGHBORHOOD_COLLECTIVES',1)
     cuda_aware = 0
     if hasattr(self, 'ompi_major_version'):
-      openmpi_cuda_test = '#include<mpi.h>\n #include <mpi-ext.h>\n #if defined(MPIX_CUDA_AWARE_SUPPORT) && MPIX_CUDA_AWARE_SUPPORT\n #else\n #error This OpenMPI is not CUDA-aware\n #endif\n'
+      openmpi_cuda_test = '#include<mpi.h>\n #include <mpi-ext.h>\n #if defined(MPIX_CUDA_AWARE_SUPPORT) && MPIX_CUDA_AWARE_SUPPORT\n #else\n #error This Open MPI is not CUDA-aware\n #endif\n'
       if self.checkCompile(openmpi_cuda_test):
         cuda_aware = 1
     elif hasattr(self, 'mpich_numversion'):
@@ -555,13 +544,21 @@ Unable to run hostname to check the network')
     ''' + ('if (MPI_Reduce_local_c(0,0,0,MPI_INT,MPI_SUM)) return 1;\n' if self.haveReduceLocal == 1 else '')):
       self.addDefine('HAVE_MPI_LARGE_COUNT', 1)
 
+    if self.checkLink('#include <mpi.h>\n',
+    '''
+      MPI_Request req;
+      MPI_Info    info;
+      if (MPI_Neighbor_alltoallv_init(0,0,0,MPI_INT,0,0,0,MPI_INT,MPI_COMM_WORLD,info,&req)) return 1;
+    '''):
+      self.addDefine('HAVE_MPI_PERSISTENT_NEIGHBORHOOD_COLLECTIVES', 1)
+
     self.compilers.CPPFLAGS = oldFlags
     self.compilers.LIBS = oldLibs
     self.logWrite(self.framework.restoreLog())
     return
 
   def configureMPIX(self):
-    '''Check for experimental functions added by MPICH or OpenMPI as MPIX'''
+    '''Check for experimental functions added by MPICH or Open MPI as MPIX'''
     # mpich-4.2 has a bug fix (PR6454). Without it, we could not use MPIX stream
     if (hasattr(self, 'mpich_numversion') and int(self.mpich_numversion) >= 40200000):
       oldFlags = self.compilers.CPPFLAGS
@@ -636,8 +633,6 @@ Unable to run hostname to check the network')
     self.framework.addDefine('MPI_Comm_create_errhandler(p_err_fun,p_errhandler)', 'MPI_Errhandler_create((p_err_fun),(p_errhandler))')
     self.framework.addDefine('MPI_Comm_set_errhandler(comm,p_errhandler)', 'MPI_Errhandler_set((comm),(p_errhandler))')
     self.logWrite(self.framework.restoreLog())
-    self.commf2c = 1
-    self.commc2f = 1
     self.usingMPIUni = 1
     self.found = 1
     self.version = 'PETSc MPIUNI uniprocessor MPI replacement'
@@ -645,11 +640,11 @@ Unable to run hostname to check the network')
     return
 
   def checkDownload(self):
-    '''Check if we should download MPICH or OpenMPI'''
+    '''Check if we should download MPICH or Open MPI'''
     if 'download-mpi' in self.argDB and self.argDB['download-mpi']:
       raise RuntimeError('Option --download-mpi does not exist! Use --download-mpich or --download-openmpi instead.')
     if self.argDB['download-mpich'] and self.argDB['download-openmpi']:
-      raise RuntimeError('Cannot install more than one of OpenMPI or  MPICH for a single configuration. \nUse different PETSC_ARCH if you want to be able to switch between two')
+      raise RuntimeError('Cannot install more than one of Open MPI or  MPICH for a single configuration. \nUse different PETSC_ARCH if you want to be able to switch between two')
     return None
 
   def SGIMPICheck(self):
@@ -694,7 +689,6 @@ Unable to run hostname to check the network')
     if self.fortran.fortranIsF90:
       self.log.write('Checking for mpi.mod\n')
       if self.libraries.check(self.lib,'', call = '       use mpi\n       integer(kind=selected_int_kind(5)) ierr,rank\n       call mpi_init(ierr)\n       call mpi_comm_rank(MPI_COMM_WORLD,rank,ierr)\n'):
-        self.havef90module = 1
         self.addDefine('HAVE_MPI_F90MODULE', 1)
     self.compilers.FPPFLAGS = oldFlags
     self.libraries.popLanguage()
@@ -770,7 +764,7 @@ Unable to run hostname to check the network')
       self.isNecMPI = 1
       self.addDefine('HAVE_NECMPI',1)
 
-    # IBM Spectrum MPI is derived from OpenMPI, we do not yet have specific tests for it
+    # IBM Spectrum MPI is derived from Open MPI, we do not yet have specific tests for it
     # https://www.ibm.com/us-en/marketplace/spectrum-mpi
     openmpi_test = '#include <mpi.h>\nint ompi_major = OMPI_MAJOR_VERSION;\nint ompi_minor = OMPI_MINOR_VERSION;\nint ompi_release = OMPI_RELEASE_VERSION;\n'
     if self.checkCompile(openmpi_test):
@@ -788,7 +782,7 @@ Unable to run hostname to check the network')
         self.mpi_pkg_version = '  OMPI_VERSION: '+ompi_major_version+'.'+ompi_minor_version+'.'+ompi_release_version+'\n'
         MPI_VER = '  OMPI_VERSION: '+ompi_major_version+'.'+ompi_minor_version+'.'+ompi_release_version
       except:
-        self.logPrint('Unable to parse OpenMPI version from header. Probably a buggy preprocessor')
+        self.logPrint('Unable to parse Open MPI version from header. Probably a buggy preprocessor')
     if MPI_VER:
       self.compilers.CPPFLAGS = oldFlags
       self.mpi_pkg_version = MPI_VER+'\n'
@@ -816,7 +810,7 @@ Unable to run hostname to check the network')
   def findMPIIncludeAndLib(self):
     '''Find MPI include paths and libraries from "mpicc -show" or Cray "cc --cray-print-opts=cflags/libs" and save.'''
     '''When the underlying C++ compiler used by CUDA or HIP is not the same'''
-    '''as the MPICXX compiler (if any), the includes are needed for for compiling with'''
+    '''as the MPICXX compiler (if any), the includes are needed for compiling with'''
     '''the CUDA or HIP compiler or the Kokkos compiler, and the libraries are needed'''
     '''when the Kokkos compiler wrapper is linking a Kokkos application.'''
     needed=False
